SystemSchedule

Struct SystemSchedule 

pub struct SystemSchedule { /* private fields */ }
Holds systems and conditions of a Schedule sorted in topological order (along with dependency information for multi_threaded execution).

Since the arrays are sorted in the same order, elements are referenced by their index. FixedBitSet is used as a smaller, more efficient substitute of HashSet<usize>.

Implementations

Source

impl SystemSchedule

pub const fn new() -> SystemSchedule

Creates an empty SystemSchedule.

pub unsafe fn systems_mut(&mut self) -> &mut Vec<SystemWithAccess>

Accessor to allow running systems from a custom executor

Safety
  • The only allowed mutations are from calling methods on the System trait. Replacing systems in the returned Vec should be considered undefined behavior.